from setuptools import setup, find_packages

setup(
    name="affilipy",
    version='0.1.1',
    description='Replace other users affiliate link to own one.',
    author='Islands5',
    license='MIT',
    packages=find_packages(),
    author_email='five.islands.04010613@gmail.com',
    url='https://github.com/islands5/affilipy',
)
